==> lifestyle-sylius-rest-client-bundle-2.1.0-420872.zip: src/Services/ProductOption/Version1/GeneralModels/Response/ProductOption.php <==
<?php

/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Response;

use Doctrine\Common\Collections\ArrayCollection;
use JMS\Serializer\Annotation as Serializer;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Translation;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Value;

/**
 * Class ProductOption
 * @package Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\Get\Model\Response
 */
class ProductOption
{
    /**
     * @Serializer\Type("int")
     * @Serializer\SerializedName("id")
     * @var int
     */
    private $identifier;

    /**
     * @Serializer\Type("string")
     * @var string
     */
    private $code;

    /**
     * @Serializer\Type("int")
     * @var int
     */
    private $position;

    /**
     * @Serializer\SerializedName("values")
     * @Serializer\Type("array<Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Value>")
     * @var Value[]
     */
    private $values;

    /**
     * @Serializer\SerializedName("translations")
     * @Serializer\Type("ArrayCollection")
     * @var ArrayCollection|Translation[]
     */
    private $translations;

    /**
     * @Serializer\SerializedName("links")
     * @Serializer\Type("int")
     * @var int
     */
    private $links;

    /**
     * ProductOption constructor.
     */
    public function __construct()
    {
        $this->values = [];
        $this->translations = new ArrayCollection();
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->identifier;
    }

    /**
     * @param int $identifier
     * @return ProductOption
     */
    public function setId(int $identifier): ProductOption
    {
        $this->identifier = $identifier;
        return $this;
    }

    /**
     * @return string
     */
    public function getCode(): string
    {
        return $this->code;
    }

    /**
     * @param string $code
     * @return ProductOption
     */
    public function setCode(string $code): ProductOption
    {
        $this->code = $code;
        return $this;
    }

    /**
     * @return int
     */
    public function getPosition(): int
    {
        return $this->position;
    }

    /**
     * @param int $position
     * @return ProductOption
     */
    public function setPosition(int $position): ProductOption
    {
        $this->position = $position;
        return $this;
    }

    /**
     * @return Value[]
     */
    public function getValues(): array
    {
        return $this->values;
    }

    /**
     * @param Value[] $values
     * @return ProductOption
     */
    public function setValues(array $values): ProductOption
    {
        $this->values = $values;
        return $this;
    }

    /**
     * @return Translation[]
     */
    public function getTranslations()
    {
        return $this->translations;
    }

    /**
     * @param Translation[] $translations
     * @return ProductOption
     */
    public function setTranslations(array $translations): ProductOption
    {
        $this->translations = $translations;
        return $this;
    }

    /**
     * @return int
     */
    public function getLinks(): int
    {
        return $this->links;
    }

    /**
     * @param int $links
     * @return ProductOption
     */
    public function setLinks(int $links): ProductOption
    {
        $this->links = $links;
        return $this;
    }

    /**
     * @param string $optionCode
     * @param string $optionValue
     * @return bool
     */
    public function hasOption(string $optionCode, string $optionValue): bool
    {
        $code = $this->buildCode($optionCode, $optionValue);
        foreach ($this->values as $value) {
            if ($value->getCode() === $code) {
                return true;
            }
        }

        return false;
    }

    /**
     * @param string $optionCode
     * @param string $optionValue
     * @return string
     */
    static public function buildCode(string $optionCode, string $optionValue): string
    {
        return $optionCode . '_' . preg_replace('/[^a-z0-9_]/', '_', strtolower($optionValue));
    }
}

==> lifestyle-sylius-rest-client-bundle-2.5.0-721843.zip: src/Services/ProductOption/Version1/GeneralModels/Response/ProductOption.php <==
<?php

/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Response;

use Doctrine\Common\Collections\ArrayCollection;
use JMS\Serializer\Annotation as Serializer;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Translation;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Value;

/**
 * Class ProductOption
 * @package Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\Get\Model\Response
 */
class ProductOption
{
    /**
     * @Serializer\Type("int")
     * @Serializer\SerializedName("id")
     * @var int
     */
    private $identifier;

    /**
     * @Serializer\Type("string")
     * @var string
     */
    private $code;

    /**
     * @Serializer\Type("int")
     * @var int
     */
    private $position;

    /**
     * @Serializer\SerializedName("values")
     * @Serializer\Type("array<Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Value>")
     * @var Value[]
     */
    private $values;

    /**
     * @Serializer\SerializedName("translations")
     * @Serializer\Type("ArrayCollection")
     * @var ArrayCollection|Translation[]
     */
    private $translations;

    /**
     * @Serializer\SerializedName("links")
     * @Serializer\Type("int")
     * @var int
     */
    private $links;

    /**
     * ProductOption constructor.
     */
    public function __construct()
    {
        $this->values = [];
        $this->translations = new ArrayCollection();
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->identifier;
    }

    /**
     * @param int $identifier
     * @return ProductOption
     */
    public function setId(int $identifier): ProductOption
    {
        $this->identifier = $identifier;
        return $this;
    }

    /**
     * @return string
     */
    public function getCode(): string
    {
        return $this->code;
    }

    /**
     * @param string $code
     * @return ProductOption
     */
    public function setCode(string $code): ProductOption
    {
        $this->code = $code;
        return $this;
    }

    /**
     * @return int
     */
    public function getPosition(): int
    {
        return $this->position;
    }

    /**
     * @param int $position
     * @return ProductOption
     */
    public function setPosition(int $position): ProductOption
    {
        $this->position = $position;
        return $this;
    }

    /**
     * @return Value[]
     */
    public function getValues(): array
    {
        return $this->values;
    }

    /**
     * @param Value[] $values
     * @return ProductOption
     */
    public function setValues(array $values): ProductOption
    {
        $this->values = $values;
        return $this;
    }

    /**
     * @return Translation[]
     */
    public function getTranslations()
    {
        return $this->translations;
    }

    /**
     * @param Translation[] $translations
     * @return ProductOption
     */
    public function setTranslations(array $translations): ProductOption
    {
        $this->translations = $translations;
        return $this;
    }

    /**
     * @return int
     */
    public function getLinks(): int
    {
        return $this->links;
    }

    /**
     * @param int $links
     * @return ProductOption
     */
    public function setLinks(int $links): ProductOption
    {
        $this->links = $links;
        return $this;
    }

    /**
     * @param string $optionCode
     * @param string $optionValue
     * @return bool
     */
    public function hasOption(string $optionCode, string $optionValue): bool
    {
        $code = $this->buildCode($optionCode, (string)$optionValue);
        foreach ($this->values as $value) {
            if ($value->getCode() === $code) {
                return true;
            }
        }

        return false;
    }

    /**
     * @param string $optionCode
     * @param string $optionValue
     * @return string
     */
    static public function buildCode(string $optionCode, string $optionValue): string
    {
        return $optionCode . '_' . preg_replace('/[^a-z0-9_]/', '_', strtolower($optionValue));
    }
}
